#[non_exhaustive]pub struct Field {
pub decl_name: &'static str,
pub flatten: bool,
pub sources: Vec<Source>,
pub aliases: Vec<&'static str>,
pub rename: Option<&'static str>,
pub serde_rename: Option<&'static str>,
pub metadata: Option<&'static Metadata>,
}Expand description
Information about struct field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decl_name: &'static strField declare name in struct definition.
flatten: boolField flatten, this field will extracted from request.
sources: Vec<Source>Field sources.
aliases: Vec<&'static str>Field aliaes.
rename: Option<&'static str>Field rename defined by #[derive(salvo(extract(rename="")))].
serde_rename: Option<&'static str>Field rename defined by #[derive(serde(rename=""))].
metadata: Option<&'static Metadata>Field metadata, this is used for nested extractible types.
Implementations
sourceimpl Field
impl Field
sourcepub fn with_sources(decl_name: &'static str, sources: Vec<Source>) -> Field
pub fn with_sources(decl_name: &'static str, sources: Vec<Source>) -> Field
Create a new field with the given name and kind, and the given sources.
sourcepub fn metadata(self, metadata: &'static Metadata) -> Field
pub fn metadata(self, metadata: &'static Metadata) -> Field
Sets the metadata to the field type.
sourcepub fn add_source(self, source: Source) -> Field
pub fn add_source(self, source: Source) -> Field
Add a source to sources list.
sourcepub fn aliases(self, aliases: Vec<&'static str>) -> Field
pub fn aliases(self, aliases: Vec<&'static str>) -> Field
Sets the aliases list to a new value.
sourcepub fn serde_rename(self, serde_rename: &'static str) -> Field
pub fn serde_rename(self, serde_rename: &'static str) -> Field
Sets the rename to the given value.