dipper::core::fuse::flex

Struct FlexFusewire

source
pub struct FlexFusewire { /* private fields */ }
A simple fusewire.

Implementations

source

impl FlexFusewire

source

pub fn new(info: FuseInfo) -> FlexFusewire

Create a new FlexFusewire.

source

pub fn builder() -> FlexFactory

Create a new FlexFactory.

source

pub fn tcp_idle_timeout(&self) -> Duration

Get the timeout for close the idle tcp connection.

source

pub fn tcp_frame_timeout(&self) -> Duration

Get the timeout for close the connection if frame can not be recived.

source

pub fn tls_handshake_timeout(&self) -> Duration

Set the timeout for close the connection if handshake not finished.