pub struct FlexFusewire { /* private fields */ }Expand description
A simple fusewire.
Implementations
Sourceimpl FlexFusewire
impl FlexFusewire
Sourcepub fn new(info: FuseInfo) -> FlexFusewire
pub fn new(info: FuseInfo) -> FlexFusewire
Create a new FlexFusewire.
Sourcepub fn builder() -> FlexFactory
pub fn builder() -> FlexFactory
Create a new FlexFactory.
Sourcepub fn tcp_idle_timeout(&self) -> Duration
pub fn tcp_idle_timeout(&self) -> Duration
Get the timeout for close the idle tcp connection.
Sourcepub fn tcp_frame_timeout(&self) -> Duration
pub fn tcp_frame_timeout(&self) -> Duration
Get the timeout for close the connection if frame can not be received.
Sourcepub fn tls_handshake_timeout(&self) -> Duration
pub fn tls_handshake_timeout(&self) -> Duration
Set the timeout for close the connection if handshake not finished.