ParseError

Enum ParseError 

#[non_exhaustive]
pub enum ParseError {
Show 21 variants InvalidContentType, EmptyBody, NotExist, ParseFromStr, InvalidStatusCode(InvalidStatusCode), InvalidMethod(InvalidMethod), InvalidUri(InvalidUri), InvalidUriParts(InvalidUriParts), InvalidHeaderName(InvalidHeaderName), InvalidHeaderValue(InvalidHeaderValue), Deserialize(Error), DuplicateKey, NotMultipart, NotFormData, InvalidRange, Multer(Error), Io(Error), Hyper(Error), Utf8(Utf8Error), SerdeJson(Error), Other(Box<dyn Error + Send + Sync>),
}
Errors happened when read data from http request.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidContentType

The Hyper request did not have a valid Content-Type header.



EmptyBody

The Hyper request’s body is empty.



NotExist

The Hyper request’s body is empty.



ParseFromStr

Parse error when parse from str.



InvalidStatusCode(InvalidStatusCode)

A possible error value when converting a StatusCode from a u16 or &str This error indicates that the supplied input was not a valid number, was less than 100, or was greater than 999.



InvalidMethod(InvalidMethod)

A possible error value when converting Method from bytes.



InvalidUri(InvalidUri)

An error resulting from a failed attempt to construct a URI.



InvalidUriParts(InvalidUriParts)

An error resulting from a failed attempt to construct a URI.



InvalidHeaderName(InvalidHeaderName)

A possible error when converting a HeaderName from another type.



InvalidHeaderValue(InvalidHeaderValue)

A possible error when converting a HeaderValue from a string or byte slice.



Deserialize(Error)

Deserialize error when parse from request.



DuplicateKey

DuplicateKey.



NotMultipart

The Hyper request Content-Type top-level Mime was not Multipart.



NotFormData

The Hyper request Content-Type sub-level Mime was not FormData.



InvalidRange

InvalidRange.



Multer(Error)

An multer error.



Io(Error)

An I/O error.



Hyper(Error)

An error was returned from hyper.



Utf8(Utf8Error)

An error occurred during UTF-8 processing.



SerdeJson(Error)

Serde json error.



Other(Box<dyn Error + Send + Sync>)

Custom error that does not fall under any other error kind.

Implementations

Source

impl ParseError

pub fn other(error: impl Into<Box<dyn Error + Send + Sync>>) -> ParseError

Create a custom error.