pub struct Authorization<C>(pub C)
where
C: Credentials;Expand description
Authorization header, defined in RFC7235
The Authorization header field allows a user agent to authenticate
itself with an origin server – usually, but not necessarily, after
receiving a 401 (Unauthorized) response. Its value consists of
credentials containing the authentication information of the user
agent for the realm of the resource being requested.
ABNF
Authorization = credentialsExample values
Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==Bearer fpKL54jvWmEGVoRdCNjG
Examples
use headers::Authorization;
let basic = Authorization::basic("Aladdin", "open sesame");
let bearer = Authorization::bearer("some-opaque-token").unwrap();Tuple Fields
0: CImplementations
sourceimpl Authorization<Basic>
impl Authorization<Basic>