pub struct ProxyAuthorization<C>(pub C)
where
C: Credentials;Expand description
Proxy-Authorization header, defined in RFC7235
The Proxy-Authorization header field allows a user agent to authenticate
itself with an HTTP proxy – usually, but not necessarily, after
receiving a 407 (Proxy Authentication Required) response and the
Proxy-Authenticate header. Its value consists of credentials containing
the authentication information of the user agent for the realm of the
resource being requested.
ABNF
Proxy-Authorization = credentialsExample values
Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==Bearer fpKL54jvWmEGVoRdCNjG
Examples
Tuple Fields
0: CTrait Implementations
Sourceimpl<C> Clone for ProxyAuthorization<C>where
C: Clone + Credentials,
impl<C> Clone for ProxyAuthorization<C>where
C: Clone + Credentials,
Sourcefn clone(&self) -> ProxyAuthorization<C>
fn clone(&self) -> ProxyAuthorization<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C> Debug for ProxyAuthorization<C>where
C: Debug + Credentials,
impl<C> Debug for ProxyAuthorization<C>where
C: Debug + Credentials,
Sourceimpl<C> Header for ProxyAuthorization<C>where
C: Credentials,
impl<C> Header for ProxyAuthorization<C>where
C: Credentials,
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.
Sourcefn decode<'i, I>(values: &mut I) -> Result<ProxyAuthorization<C>, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<ProxyAuthorization<C>, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.Sourceimpl<C> PartialEq for ProxyAuthorization<C>where
C: PartialEq + Credentials,
impl<C> PartialEq for ProxyAuthorization<C>where
C: PartialEq + Credentials,
impl<C> StructuralPartialEq for ProxyAuthorization<C>where
C: Credentials,