pub struct Name<'a> { /* private fields */ }Expand description
A section of a Mime.
For instance, for the Mime image/svg+xml, it contains 3 Names,
image, svg, and xml.
In most cases, Names are compared ignoring case.
Implementations
Sourceimpl<'a> Name<'a>
impl<'a> Name<'a>
Sourcepub fn as_str(&self) -> &'a str
pub fn as_str(&self) -> &'a str
Get the value of this Name as a string.
Note that the borrow is not tied to &self but the 'a lifetime, allowing the
string to outlive Name. Alternately, there is an impl<'a> From<Name<'a>> for &'a str
which isn’t rendered by Rustdoc, that can be accessed using str::from(name) or name.into().