FlowCtrl

Struct FlowCtrl 

pub struct FlowCtrl { /* private fields */ }
Control the flow of execute handlers.

When a request is coming, Router will detect it and get the matched router. And then salvo will collect all handlers (including added as middlewares) from the matched router tree. All handlers in this list will executed one by one.

Each handler can use FlowCtrl to control execute flow, let the flow call next handler or skip all rest handlers.

NOTE: When Response’s status code is set, and the status code Response::is_stamped() is returns false, all remaining handlers will be skipped.

Implementations

Source

impl FlowCtrl

pub fn new(handlers: Vec<Arc<dyn Handler>>) -> FlowCtrl

Create new FlowCtrl.

pub fn has_next(&self) -> bool

Has next handler.

pub async fn call_next( &mut self, req: &mut Request, depot: &mut Depot, res: &mut Response, ) -> bool

Call next handler. If get next handler and executed, returns true``, otherwise returns false`.

NOTE: If response status code is error or is redirection, all reset handlers will be skipped.

pub fn skip_rest(&mut self)

Skip all reset handlers.

pub fn is_ceased(&self) -> bool

Check is FlowCtrl ceased.

NOTE: If handler is used as middleware, it should use is_ceased to check is flow ceased. If is_ceased returns true, the handler should skip the following logic.

pub fn cease(&mut self)

Cease all following logic.

NOTE: This function will mark is_ceased as true, but whether the subsequent logic can be skipped depends on whether the middleware correctly checks is_ceased and skips the subsequent logic.