pub struct Server<A> { /* private fields */ }Expand description
HTTP Server.
A Server is created to listen on a port, parse HTTP requests, and hand them off to a Service.
Implementations
sourceimpl<A> Server<A>
impl<A> Server<A>
sourcepub fn with_http_builder(acceptor: A, builder: HttpBuilder) -> Server<A>
pub fn with_http_builder(acceptor: A, builder: HttpBuilder) -> Server<A>
Create new Server with Acceptor and [HttpBuilder].
sourcepub fn fuse_factory<F>(self, factory: F) -> Server<A>
pub fn fuse_factory<F>(self, factory: F) -> Server<A>
Set the fuse factory.
sourcepub fn handle(&self) -> ServerHandle
pub fn handle(&self) -> ServerHandle
Get a ServerHandle to stop server.
sourcepub fn stop_forcible(&self)
pub fn stop_forcible(&self)
Force stop server.
Call this function will stop server immediately.
sourcepub fn stop_graceful(&self, timeout: impl Into<Option<Duration>>)
pub fn stop_graceful(&self, timeout: impl Into<Option<Duration>>)
Graceful stop server.
Call this function will stop server after all connections are closed.
You can specify a timeout to force stop server.
If timeout is None, it will wait util all connections are closed.
sourcepub fn http2_mut(&mut self) -> &mut Builder<TokioExecutor>
pub fn http2_mut(&mut self) -> &mut Builder<TokioExecutor>
Use this function to set http2 protocol.