dipper::core::writing

Struct Redirect

source
pub struct Redirect { /* private fields */ }
Response that redirects the request to another location.

Example

use salvo_core::prelude::*;

#[handler]
async fn hello(res: &mut Response) {
    res.render(Redirect::found("https://www.rust-lang.org/"))
}

Implementations

source

impl Redirect

source

pub fn other(uri: impl TryInto<Uri>) -> Redirect

Create a new Redirect that uses a 303 See Other status code.

This redirect instructs the client to change the method to GET for the subsequent request to the given uri, which is useful after successful form submission, file upload or when you generally don’t want the redirected-to page to observe the original request method and body (if non-empty).

Panics

If uri isn’t a valid Uri.

source

pub fn temporary(uri: impl TryInto<Uri>) -> Redirect

Create a new Redirect that uses a 307 Temporary Redirect status code.

Panics

If uri isn’t a valid Uri.

source

pub fn permanent(uri: impl TryInto<Uri>) -> Redirect

Create a new Redirect that uses a 308 Permanent Redirect status code.

Panics

If uri isn’t a valid Uri.

source

pub fn found(uri: impl TryInto<Uri>) -> Redirect

Create a new Redirect that uses a 302 Found status code.

This is the same as Redirect::temporary, except the status code is older and thus supported by some legacy applications that doesn’t understand the newer one, but some of those applications wrongly apply Redirect::other (303 See Other) semantics for this status code. It should be avoided where possible.

Panics

If uri isn’t a valid Uri.

source

pub fn with_status_code( status_code: StatusCode, uri: impl TryInto<Uri>, ) -> Result<Redirect, Error>

Create a new Redirect that uses a status code.