ModuleBuilder

Struct ModuleBuilder 

pub struct ModuleBuilder<M: Module> { /* private fields */ }
Builds a Module. Component parameters can be set, and both components and providers implementations can be overridden.

Implementations

Source

impl<M: Module> ModuleBuilder<M>

pub fn with_submodules(submodules: M::Submodules) -> Self

Create a ModuleBuilder by providing the module’s submodules.

pub fn with_component_parameters<C: Component<M>>( self, params: C::Parameters, ) -> Self
where M: HasComponent<C::Interface>,

Set the parameters of the specified component. If the parameters are not manually set, the defaults will be used.

pub fn with_component_override<I: Interface + ?Sized>( self, component: Box<I>, ) -> Self
where M: HasComponent<I>,

Override a component implementation. This method is best used when the overriding component has no injected dependencies.

pub fn with_component_override_fn<I: Interface + ?Sized>( self, component_fn: ComponentFn<M, I>, ) -> Self
where M: HasComponent<I>,

Override a component implementation. This method is best used when the overriding component has injected dependencies.