Interface

Trait Interface 

pub trait Interface:
    Any
    + Send
    + Sync
    + Depends {
    // Provided methods
    fn manifest(&self) -> Manifest { ... }
    fn route(self: Arc<Self>, blank_router: Router) -> Router { ... }
}
Interfaces must be 'static in order to be stored in a module (hence the Any requirement).

The thread_safe feature is turned on, which requires interfaces to also implement Send and Sync.

Provided Methods

fn manifest(&self) -> Manifest

fn route(self: Arc<Self>, blank_router: Router) -> Router

Implementors