pub enum MrConn {
Master(Arc<DatabaseConnection>),
Replica(Arc<DatabaseConnection>),
}Expand description
Distinguish between master and replica database connections.
Variants
Master(Arc<DatabaseConnection>)
Replica(Arc<DatabaseConnection>)
Implementations
Sourceimpl MrConn
impl MrConn
Sourcepub fn db(&self) -> &DatabaseConnection
pub fn db(&self) -> &DatabaseConnection
Get a reference to the database connection object.
Sourcepub fn expand(&self) -> (&DatabaseConnection, bool)
pub fn expand(&self) -> (&DatabaseConnection, bool)
Get a reference to the database connection object, and also tell whether it is the master database.
Methods from Deref<Target = DatabaseConnection>