pub enum ContentTransferEncoding {
SevenBit,
QuotedPrintable,
Base64,
EightBit,
Binary,
}Expand description
Content-Transfer-Encoding of the body
The Message builder takes care of choosing the most
efficient encoding based on the chosen body, so in most
use-caches this header shouldn’t be set manually.
Variants
SevenBit
ASCII
QuotedPrintable
Quoted-Printable encoding
Base64
base64 encoding
EightBit
Requires 8BITMIME
Binary
Binary data