pub struct Error { /* private fields */ }Expand description
The Errors that may occur when sending an email over SMTP
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_response(&self) -> bool
pub fn is_response(&self) -> bool
Returns true if the error is from response
Sourcepub fn is_transient(&self) -> bool
pub fn is_transient(&self) -> bool
Returns true if the error is a transient SMTP error
Sourcepub fn is_permanent(&self) -> bool
pub fn is_permanent(&self) -> bool
Returns true if the error is a permanent SMTP error
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if the error is caused by a timeout
Sourcepub fn is_transport_shutdown(&self) -> bool
pub fn is_transport_shutdown(&self) -> bool
Returns true if the error is because the transport was shut down