dipper::oapi

Enum BasicType

pub enum BasicType {
    Object,
    String,
    Integer,
    Number,
    Boolean,
    Array,
    Null,
}
Represents data type fragment of Schema.

BasicType is used to create a SchemaType that defines the type of the Schema. SchemaType can be created from a single BasicType or multiple BasicTypes according to the OpenAPI 3.1 spec. Since the OpenAPI 3.1 is fully compatible with JSON schema the definiton of the type property comes from JSON Schema type.

Examples

Create nullable string SchemaType

let _: SchemaType = [BasicType::String, BasicType::Null].into_iter().collect();

Create string SchemaType

let _ = SchemaType::basic(BasicType::String);

Variants



Object

Used with Object to describe schema that has properties describing fields. have



String

Indicates string type of content. Used with Object on a string field.



Integer

Indicates integer type of content. Used with Object on a number field.



Number

Indicates floating point number type of content. Used with Object on a number field.



Boolean

Indicates boolean type of content. Used with Object on a bool field.



Array

Used with Array. Indicates array type of content.



Null

Null type. Used together with other type to indicate nullable values.