Array

Struct Array 

#[non_exhaustive]
pub struct Array { pub schema_type: SchemaType, pub title: Option<String>, pub items: Box<RefOr<Schema>>, pub description: Option<String>, pub deprecated: Option<Deprecated>, pub examples: Vec<Value>, pub default_value: Option<Value>, pub max_items: Option<usize>, pub min_items: Option<usize>, pub unique_items: bool, pub xml: Option<Xml>, pub extensions: BTreeMap<String, Value>, }
Array represents Vec or slice type of items.

See Schema::Array for more details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
schema_type: SchemaType

Type will always be SchemaType::Array

title: Option<String>

Changes the Array title.

items: Box<RefOr<Schema>>

Schema representing the array items type.

description: Option<String>

Description of the Array. Markdown syntax is supported.

deprecated: Option<Deprecated>

Marks the Array deprecated.

examples: Vec<Value>

Examples shown in UI of the value for richer documentation.

default_value: Option<Value>

Default value which is provided when user has not provided the input in Swagger UI.

max_items: Option<usize>

Max length of the array.

min_items: Option<usize>

Min length of the array.

unique_items: bool

Setting this to true will validate successfully if all elements of this Array are unique.

xml: Option<Xml>

Xml format of the array.

extensions: BTreeMap<String, Value>

Optional extensions x-something.

Implementations

Source

impl Array

pub fn new() -> Array

Construct a new Array component from given Schema.

Examples

Create a String array component.

let string_array = Array::new().items(Object::with_type(BasicType::String));
pub fn items<I>(self, items: I) -> Array
where I: Into<RefOr<Schema>>,

Set Schema type for the Array.

pub fn schema_type<T>(self, schema_type: T) -> Array
where T: Into<SchemaType>,

Change type of the array e.g. to change type to string use value SchemaType::Type(Type::String).

Examples

Make nullable string array.

let _ = Array::new()
    .schema_type(SchemaType::from_iter([BasicType::Array, BasicType::Null]))
    .items(Object::with_type(BasicType::String));
pub fn title(self, title: impl Into<String>) -> Array

Add or change the title of the Array.

pub fn description(self, description: impl Into<String>) -> Array

Add or change description of the property. Markdown syntax is supported.

pub fn deprecated(self, deprecated: Deprecated) -> Array

Add or change deprecated status for Array.

pub fn example<V>(self, example: V) -> Array
where V: Into<Value>,

Add or change example shown in UI of the value for richer documentation.

pub fn examples<I, V>(self, examples: I) -> Array
where I: IntoIterator<Item = V>, V: Into<Value>,

Add or change example shown in UI of the value for richer documentation.

pub fn default_value(self, default: Value) -> Array

Add or change default value for the object which is provided when user has not provided the input in Swagger UI.

pub fn max_items(self, max_items: usize) -> Array

Set maximum allowed length for Array.

pub fn min_items(self, min_items: usize) -> Array

Set minimum allowed length for Array.

pub fn unique_items(self, unique_items: bool) -> Array

Set or change whether Array should enforce all items to be unique.

pub fn xml(self, xml: Xml) -> Array

Set Xml formatting for Array.

pub fn add_extension<K>(self, key: K, value: Value) -> Array
where K: Into<String>,

Add openapi extension (x-something) for Array.