#[non_exhaustive]pub struct Contact {
pub name: Option<String>,
pub url: Option<String>,
pub email: Option<String>,
}Expand description
OpenAPI Contact information of the API.
You can use Contact::new to construct a new Contact object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>Identifying name of the contact person or organization of the API.
url: Option<String>Url pointing to contact information of the API.
email: Option<String>Email of the contact person or the organization of the API.
Implementations
Sourceimpl Contact
impl Contact
Sourcepub fn new() -> Contact
pub fn new() -> Contact
Construct a new empty Contact. This is effectively same as calling Contact::default.