#[non_exhaustive]pub struct Discriminator {
pub property_name: String,
pub mapping: BTreeMap<String, String>,
}Expand description
OpenAPI Discriminator object which can be optionally used together with
OneOf composite object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.property_name: StringDefines a discriminator property name which must be found within all composite objects.
mapping: BTreeMap<String, String>An object to hold mappings between payload values and schema names or references. This field can only be populated manually. There is no macro support and no validation.
Implementations
sourceimpl Discriminator
impl Discriminator
sourcepub fn new<I>(property_name: I) -> Discriminator
pub fn new<I>(property_name: I) -> Discriminator
Construct a new Discriminator object with property name.
Examples
Create a new Discriminator object for pet_type property.
let discriminator = Discriminator::new("pet_type");Trait Implementations
sourceimpl Clone for Discriminator
impl Clone for Discriminator
sourcefn clone(&self) -> Discriminator
fn clone(&self) -> Discriminator
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for Discriminator
impl Debug for Discriminator
sourceimpl Default for Discriminator
impl Default for Discriminator
sourcefn default() -> Discriminator
fn default() -> Discriminator
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for Discriminator
impl<'de> Deserialize<'de> for Discriminator
sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Discriminator, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Discriminator, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for Discriminator
impl PartialEq for Discriminator
sourceimpl Serialize for Discriminator
impl Serialize for Discriminator
sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Discriminator
impl StructuralPartialEq for Discriminator