#[non_exhaustive]pub struct Operation {Show 13 fields
pub tags: Vec<String>,
pub summary: Option<String>,
pub description: Option<String>,
pub operation_id: Option<String>,
pub external_docs: Option<ExternalDocs>,
pub parameters: Parameters,
pub request_body: Option<RequestBody>,
pub responses: Responses,
pub callbacks: Option<String>,
pub deprecated: Option<Deprecated>,
pub securities: Vec<SecurityRequirement>,
pub servers: Servers,
pub extensions: BTreeMap<String, Value>,
}Expand description
Implements OpenAPI Operation Object object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.List of tags used for grouping operations.
When used with derive #[salvo_oapi::endpoint(...)] attribute macro the default
value used will be resolved from handler path provided in #[openapi(paths(...))] with
#[derive(OpenApi)] macro. If path resolves to None value crate will
be used by default.
summary: Option<String>Short summary what Operation does.
When used with derive #[salvo_oapi::endpoint(...)] attribute macro the value
is taken from first line of doc comment.
description: Option<String>Long explanation of Operation behaviour. Markdown syntax is supported.
When used with derive #[salvo_oapi::endpoint(...)] attribute macro the
doc comment is used as value for description.
operation_id: Option<String>Unique identifier for the API Operation. Most typically this is mapped to handler function name.
When used with derive #[salvo_oapi::endpoint(...)] attribute macro the handler function
name will be used by default.
external_docs: Option<ExternalDocs>Additional external documentation for this operation.
parameters: ParametersList of applicable parameters for this Operation.
request_body: Option<RequestBody>Optional request body for this Operation.
responses: ResponsesList of possible responses returned by the Operation.
callbacks: Option<String>Callback information.
deprecated: Option<Deprecated>Define whether the operation is deprecated or not and thus should be avoided consuming.
securities: Vec<SecurityRequirement>Declaration which security mechanisms can be used for for the operation. Only one
SecurityRequirement must be met.
Security for the Operation can be set to optional by adding empty security with
SecurityRequirement::default.
servers: Serversextensions: BTreeMap<String, Value>Optional extensions “x-something”
Implementations
Sourceimpl Operation
impl Operation
Add or change tags of the Operation.
Sourcepub fn description<S>(self, description: S) -> Operation
pub fn description<S>(self, description: S) -> Operation
Add or change description of the Operation.
Sourcepub fn operation_id<S>(self, operation_id: S) -> Operation
pub fn operation_id<S>(self, operation_id: S) -> Operation
Add or change operation id of the Operation.
Sourcepub fn parameters<I, P>(self, parameters: I) -> Operation
pub fn parameters<I, P>(self, parameters: I) -> Operation
Add or change parameters of the Operation.
Sourcepub fn add_parameter<P>(self, parameter: P) -> Operation
pub fn add_parameter<P>(self, parameter: P) -> Operation
Append parameter to Operation parameters and returns Self.
Sourcepub fn request_body(self, request_body: RequestBody) -> Operation
pub fn request_body(self, request_body: RequestBody) -> Operation
Add or change request body of the Operation.
Sourcepub fn add_response<S, R>(self, code: S, response: R) -> Operation
pub fn add_response<S, R>(self, code: S, response: R) -> Operation
Sourcepub fn deprecated<D>(self, deprecated: D) -> Operationwhere
D: Into<Deprecated>,
pub fn deprecated<D>(self, deprecated: D) -> Operationwhere
D: Into<Deprecated>,
Add or change deprecated status of the Operation.
Sourcepub fn securities<I>(self, securities: I) -> Operationwhere
I: IntoIterator<Item = SecurityRequirement>,
pub fn securities<I>(self, securities: I) -> Operationwhere
I: IntoIterator<Item = SecurityRequirement>,
Add or change list of SecurityRequirements that are available for Operation.
Sourcepub fn add_security(self, security: SecurityRequirement) -> Operation
pub fn add_security(self, security: SecurityRequirement) -> Operation
Append SecurityRequirement to Operation security requirements and returns Self.
Sourcepub fn servers<I>(self, servers: I) -> Operationwhere
I: IntoIterator<Item = Server>,
pub fn servers<I>(self, servers: I) -> Operationwhere
I: IntoIterator<Item = Server>,
Sourcepub fn add_server(self, server: Server) -> Operation
pub fn add_server(self, server: Server) -> Operation