#[non_exhaustive]pub struct PathItem {
pub summary: Option<String>,
pub description: Option<String>,
pub servers: Servers,
pub parameters: Parameters,
pub operations: Operations,
}Expand description
Implements OpenAPI Path Item Object what describes Operations available on
a single path.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.summary: Option<String>Optional summary intended to apply all operations in this PathItem.
description: Option<String>Optional description intended to apply all operations in this PathItem.
Description supports markdown syntax.
servers: ServersAlternative Server array to serve all Operations in this PathItem overriding
the global server array.
parameters: ParametersList of Parameters common to all Operations in this PathItem. Parameters cannot
contain duplicate parameters. They can be overridden in Operation level but cannot be
removed there.
operations: OperationsMap of operations in this PathItem. Operations can hold only one operation
per PathItemType.
Implementations
sourceimpl PathItem
impl PathItem
sourcepub fn new<O>(path_item_type: PathItemType, operation: O) -> PathItem
pub fn new<O>(path_item_type: PathItemType, operation: O) -> PathItem
Construct a new PathItem with provided Operation mapped to given PathItemType.
sourcepub fn append(&mut self, other: &mut PathItem)
pub fn append(&mut self, other: &mut PathItem)
Moves all elements from other into self, leaving other empty.
If a key from other is already present in self, the respective
value from self will be overwritten with the respective value from other.
sourcepub fn add_operation<O>(
self,
path_item_type: PathItemType,
operation: O,
) -> PathItem
pub fn add_operation<O>( self, path_item_type: PathItemType, operation: O, ) -> PathItem
Append a new Operation by PathItemType to this PathItem. Operations can
hold only one operation per PathItemType.
sourcepub fn summary<S>(self, summary: S) -> PathItem
pub fn summary<S>(self, summary: S) -> PathItem
Add or change summary intended to apply all operations in this PathItem.
sourcepub fn description<S>(self, description: S) -> PathItem
pub fn description<S>(self, description: S) -> PathItem
Add or change optional description intended to apply all operations in this PathItem.
Description supports markdown syntax.
sourcepub fn servers<I>(self, servers: I) -> PathItemwhere
I: IntoIterator<Item = Server>,
pub fn servers<I>(self, servers: I) -> PathItemwhere
I: IntoIterator<Item = Server>,
sourcepub fn parameters<I>(self, parameters: I) -> PathItemwhere
I: IntoIterator<Item = Parameter>,
pub fn parameters<I>(self, parameters: I) -> PathItemwhere
I: IntoIterator<Item = Parameter>,