#[non_exhaustive]pub struct RequestBody {
pub description: Option<String>,
pub contents: IndexMap<String, Content>,
pub required: Option<Required>,
}Expand description
Implements OpenAPI Request Body.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>Additional description of RequestBody supporting markdown syntax.
contents: IndexMap<String, Content>Map of request body contents mapped by content type e.g. application/json.
required: Option<Required>Determines whether request body is required in the request or not.
Implementations
Sourceimpl RequestBody
impl RequestBody
Sourcepub fn new() -> RequestBody
pub fn new() -> RequestBody
Construct a new empty RequestBody. This is effectively same as calling RequestBody::default.
Sourcepub fn description<S>(self, description: S) -> RequestBody
pub fn description<S>(self, description: S) -> RequestBody
Add description for RequestBody.
Sourcepub fn required(self, required: Required) -> RequestBody
pub fn required(self, required: Required) -> RequestBody
Define RequestBody required.
Sourcepub fn add_content<S, C>(self, kind: S, content: C) -> RequestBody
pub fn add_content<S, C>(self, kind: S, content: C) -> RequestBody
Add Content by content type e.g application/json to RequestBody.
Sourcepub fn merge(&mut self, other: RequestBody)
pub fn merge(&mut self, other: RequestBody)
Fill RequestBody with values from another RequestBody.