#[non_exhaustive]pub struct Tag {
pub name: String,
pub description: Option<String>,
pub external_docs: Option<ExternalDocs>,
pub extensions: BTreeMap<String, Value>,
}Expand description
Implements OpenAPI Tag Object.
Tag can be used to provide additional metadata for tags used by path operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the tag. Should match to tag of operation.
description: Option<String>Additional description for the tag shown in the document.
external_docs: Option<ExternalDocs>Additional external documentation for the tag.
extensions: BTreeMap<String, Value>Optional extensions “x-something”
Implementations
sourceimpl Tag
impl Tag
sourcepub fn description(self, description: impl Into<String>) -> Tag
pub fn description(self, description: impl Into<String>) -> Tag
Add additional description for the tag.
sourcepub fn external_docs(self, external_docs: ExternalDocs) -> Tag
pub fn external_docs(self, external_docs: ExternalDocs) -> Tag
Add additional external documentation for the tag.