pub struct TraceFlags(/* private fields */);Expand description
Flags that can be set on a SpanContext.
The current version of the specification only supports a single flag
TraceFlags::SAMPLED.
See the W3C TraceContext specification’s trace-flags section for more details.
Implementations
Sourceimpl TraceFlags
impl TraceFlags
Sourcepub const NOT_SAMPLED: TraceFlags
pub const NOT_SAMPLED: TraceFlags
Trace flags with the sampled flag set to 0.
Spans that are not sampled will be ignored by most tracing tools.
See the sampled section of the W3C TraceContext specification for details.
Sourcepub const SAMPLED: TraceFlags
pub const SAMPLED: TraceFlags
Trace flags with the sampled flag set to 1.
Spans that are not sampled will be ignored by most tracing tools.
See the sampled section of the W3C TraceContext specification for details.
Sourcepub const fn new(flags: u8) -> TraceFlags
pub const fn new(flags: u8) -> TraceFlags
Construct new trace flags
Sourcepub fn is_sampled(&self) -> bool
pub fn is_sampled(&self) -> bool
Returns true if the sampled flag is set
Sourcepub fn with_sampled(&self, sampled: bool) -> TraceFlags
pub fn with_sampled(&self, sampled: bool) -> TraceFlags
Returns copy of the current flags with the sampled flag set.