HoopedHandler

Struct HoopedHandler 

#[non_exhaustive]
pub struct HoopedHandler { /* private fields */ }
Handler that wrap Handler to let it use middlewares.

Implementations

Source

impl HoopedHandler

pub fn new<H>(inner: H) -> HoopedHandler
where H: Handler,

Create new HoopedHandler.

pub fn hoops(&self) -> &Vec<Arc<dyn Handler>>

Get current catcher’s middlewares reference.

pub fn hoops_mut(&mut self) -> &mut Vec<Arc<dyn Handler>>

Get current catcher’s middlewares mutable reference.

pub fn hoop<H>(self, hoop: H) -> HoopedHandler
where H: Handler,

Add a handler as middleware, it will run the handler when error caught.

pub fn hoop_when<H, F>(self, hoop: H, filter: F) -> HoopedHandler
where H: Handler, F: Fn(&Request, &Depot) -> bool + Send + Sync + 'static,

Add a handler as middleware, it will run the handler when error caught.

This middleware is only effective when the filter returns true..