pub struct Json<T>(pub T);Expand description
Write serializable content to response as json content.
It will set content-type to application/json; charset=utf-8.
Example
use salvo_core::prelude::*;
use serde::Serialize;
#[derive(Serialize)]
struct User {
name: String,
}
#[handler]
async fn hello(res: &mut Response) -> Json<User> {
Json(User { name: "jobs".into() })
}Tuple Fields
0: TTrait Implementations
Sourceimpl<C> EndpointOutRegister for Json<C>where
C: ToSchema,
impl<C> EndpointOutRegister for Json<C>where
C: ToSchema,
Sourcefn register(components: &mut Components, operation: &mut Operation)
fn register(components: &mut Components, operation: &mut Operation)
Modify the OpenApi components section or current operation information with given argument. This function is called by macros internal.
Sourceimpl<C> ToResponse for Json<C>where
C: ToSchema,
impl<C> ToResponse for Json<C>where
C: ToSchema,
Sourcefn to_response(components: &mut Components) -> RefOr<Response>
fn to_response(components: &mut Components) -> RefOr<Response>
Returns a tuple of response component name (to be referenced) to a response.
Sourceimpl<C> ToResponses for Json<C>where
C: ToSchema,
impl<C> ToResponses for Json<C>where
C: ToSchema,
Sourcefn to_responses(components: &mut Components) -> Responses
fn to_responses(components: &mut Components) -> Responses
Returns an ordered map of response codes to responses.