JwtAuth

Struct JwtAuth 

#[non_exhaustive]
pub struct JwtAuth<C, D> { pub force_passed: bool, pub decoder: D, pub finders: Vec<Box<dyn JwtTokenFinder>>, /* private fields */ }
JWT Authentication middleware for Salvo.

JwtAuth extracts and validates JWT tokens from incoming requests based on the configured token finders and decoder. If valid, it stores the decoded data in the depot for later use.

Type Parameters

  • C - The claims type that will be deserialized from the JWT payload.
  • D - The decoder implementation used to validate and decode the JWT token.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
force_passed: bool

When set to true, the middleware will allow the request to proceed even if authentication fails, storing only the authentication state in the depot.

When set to false (default), requests with invalid or missing tokens will be immediately rejected with appropriate status codes.

decoder: D

The decoder used to validate and decode the JWT token.

finders: Vec<Box<dyn JwtTokenFinder>>

A list of token finders that will be used to extract the token from the request. Finders are tried in order until one returns a token.

Implementations

Source

impl<C, D> JwtAuth<C, D>
where C: DeserializeOwned + Send + Sync + 'static, D: JwtAuthDecoder + Send + Sync + 'static,

pub fn new(decoder: D) -> JwtAuth<C, D>

Create new JwtAuth.

pub fn force_passed(self, force_passed: bool) -> JwtAuth<C, D>

Sets force_passed value and return Self.

pub fn decoder_mut(&mut self) -> &mut D

Get decoder mutable reference.

pub fn finders_mut(&mut self) -> &mut Vec<Box<dyn JwtTokenFinder>>

Gets a mutable reference to the extractor list.

pub fn finders(self, finders: Vec<Box<dyn JwtTokenFinder>>) -> JwtAuth<C, D>

Sets extractor list with new value and return Self.