#[non_exhaustive]pub struct Array {
pub schema_type: SchemaType,
pub title: Option<String>,
pub items: Box<RefOr<Schema>>,
pub description: Option<String>,
pub deprecated: Option<Deprecated>,
pub examples: Vec<Value>,
pub default_value: Option<Value>,
pub max_items: Option<usize>,
pub min_items: Option<usize>,
pub unique_items: bool,
pub xml: Option<Xml>,
pub extensions: BTreeMap<String, Value>,
}Expand description
Array represents Vec or slice type of items.
See Schema::Array for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema_type: SchemaTypeType will always be SchemaType::Array
title: Option<String>Changes the Array title.
items: Box<RefOr<Schema>>Schema representing the array items type.
description: Option<String>Description of the Array. Markdown syntax is supported.
deprecated: Option<Deprecated>Marks the Array deprecated.
examples: Vec<Value>Examples shown in UI of the value for richer documentation.
default_value: Option<Value>Default value which is provided when user has not provided the input in Swagger UI.
max_items: Option<usize>Max length of the array.
min_items: Option<usize>Min length of the array.
unique_items: boolSetting this to true will validate successfully if all elements of this Array are
unique.
xml: Option<Xml>Xml format of the array.
extensions: BTreeMap<String, Value>Optional extensions x-something.
Implementations
Sourceimpl Array
impl Array
Sourcepub fn schema_type<T>(self, schema_type: T) -> Arraywhere
T: Into<SchemaType>,
pub fn schema_type<T>(self, schema_type: T) -> Arraywhere
T: Into<SchemaType>,
Change type of the array e.g. to change type to string
use value SchemaType::Type(Type::String).
Examples
Make nullable string array.
let _ = Array::new()
.schema_type(SchemaType::from_iter([BasicType::Array, BasicType::Null]))
.items(Object::with_type(BasicType::String));Sourcepub fn description(self, description: impl Into<String>) -> Array
pub fn description(self, description: impl Into<String>) -> Array
Add or change description of the property. Markdown syntax is supported.
Sourcepub fn deprecated(self, deprecated: Deprecated) -> Array
pub fn deprecated(self, deprecated: Deprecated) -> Array
Add or change deprecated status for Array.
Sourcepub fn example<V>(self, example: V) -> Array
pub fn example<V>(self, example: V) -> Array
Add or change example shown in UI of the value for richer documentation.
Sourcepub fn examples<I, V>(self, examples: I) -> Array
pub fn examples<I, V>(self, examples: I) -> Array
Add or change example shown in UI of the value for richer documentation.
Sourcepub fn default_value(self, default: Value) -> Array
pub fn default_value(self, default: Value) -> Array
Add or change default value for the object which is provided when user has not provided the input in Swagger UI.
Sourcepub fn unique_items(self, unique_items: bool) -> Array
pub fn unique_items(self, unique_items: bool) -> Array
Set or change whether Array should enforce all items to be unique.